# Quai Network Node Deployment on GCP

This guide provides instructions on how to deploy a full node or a slice node for the Quai network on Google Cloud Platform (GCP) with the correct machine, network settings, and configurations.

## Prerequisites

Ensure that you have the Google Cloud SDK (`gcloud`) installed.

Login to your GCP account using the following command:

```bash
gcloud auth login
```

## Deployment

### Full Node

To deploy a full node, use the following command:

```bash
gcloud deployment-manager deployments create <deployment-name>
--template quai-deployment.jinja \
--properties region-param:<gcp-region>,node-type:full,zone-0-0-coinbase-address:<zone-0-0-address>,zone-0-1-coinbase-address:<zone-0-1-address>,zone-0-2-coinbase-address:<zone-0-2-address>,zone-1-0-coinbase-address:<zone-1-0-address>,zone-1-1-coinbase-address:<zone-1-1-address>,zone-1-2-coinbase-address:<zone-1-2-address>,zone-2-0-coinbase-address:<zone-2-0-address>,zone-2-1-coinbase-address:<zone-2-1-address>,zone-2-2-coinbase-address:<zone-2-2-address> \
--project <project-id>
```

### Slice Node

To deploy a slice node, use the following command:

```bash
gcloud deployment-manager deployments create quai-deployment \
--template quai-deployment.jinja \
--properties region-param:<gcp-region>,node-type:slice,slice-type:<slice>,zone-0-0-coinbase-address:<zone-0-0-address>,zone-0-1-coinbase-address:<zone-0-1-address>,zone-0-2-coinbase-address:<zone-0-2-address>,zone-1-0-coinbase-address:<zone-1-0-address>,zone-1-1-coinbase-address:<zone-1-1-address>,zone-1-2-coinbase-address:<zone-1-2-address>,zone-2-0-coinbase-address:<zone-2-0-address>,zone-2-1-coinbase-address:<zone-2-1-address>,zone-2-2-coinbase-address:<zone-2-2-address> \
--project <project-id>
```

### NOTES
* The `slice-type` param is in the format of `zone-<region-number>-<zone-number>`. For example, `zone-0-0` is the slice for the first zone in the first region (cyprus1), `zone-1-1` is the slice for the second zone in the second region (paxos2), `zone-2-0` is the slice for the first zone in the third region (hydra1), etc.
* Ensure that all addresses have their prepending 0x removed.
* The `gcp-region` param specifies the region in gcp for the deployment. If in doubt, just use us-central1.
* The `project-id` param specifies the project id in gcp for the deployment. It can be found at the top left in the gcp console by clicking on the drop-down.
* If you are using a brand new GCP account, the full node will most likely not work for you. This is because you will need to request for a quota increase for the number of N2 CPUs and SSD space in the region. The slice node should work fine though.
* After deploying, follow the standard documentation for building and running `go-quai` and `go-quai-stratum`.

## POST-DEPLOYMENT
### Building and Running `go-quai`

Navigate to `/root/go-quai`
```bash
make go-quai
make run
```
    
### Building and Running `go-quai-stratum`
Navigate to `/root/go-quai-stratum`
```bash
make quai-stratum
./build/bin/quai-stratum --region=REGION-WS-PORT --zone=ZONE-WS-PORT --stratum=LISTENING-PORT
```

## SUPPORT
For any issues or queries, refer to the official Quai Network documentation or contact the support team.
